@@ -1,6 +1,7 @@
 import os
 
 import httplib2
+
 try:
     import ujson as json
 except ImportError:
@@ -8,7 +9,9 @@ except ImportError:
 import unittest
 from jsonschema import validate, Draft4Validator
 from jsonschema.exceptions import ValidationError
+
 from matminer.data_retrieval.retrieve_MPDS import MPDSDataRetrieval
+from matminer.data_retrieval.tests.base import on_ci
 
 
 class MPDSDataRetrievalTest(unittest.TestCase):
@@ -17,18 +20,19 @@ class MPDSDataRetrievalTest(unittest.TestCase):
             "elements": "K-Ag",
             "classes": "iodide",
             "props": "heat capacity",
-            "lattices": "cubic"
+            "lattices": "cubic",
         }
 
         network = httplib2.Http()
 
-        response, content = network.request('http://developer.mpds.io/mpds.schema.json')
+        response, content = network.request("http://developer.mpds.io/mpds.schema.json")
         assert response.status == 200
 
         self.schema = json.loads(content)
         Draft4Validator.check_schema(self.schema)
 
-    @unittest.skipIf('MPDS_KEY' not in os.environ, "MPDS_KEY env var not set")
+    @unittest.skipIf(on_ci.upper() == "TRUE", "Bad Datasource-GHActions pipeline")
+    @unittest.skipIf("MPDS_KEY" not in os.environ, "MPDS_KEY env var not set")
     def test_valid_answer(self):
 
         client = MPDSDataRetrieval()
@@ -37,11 +41,7 @@ class MPDSDataRetrievalTest(unittest.TestCase):
         try:
             validate(answer, self.schema)
         except ValidationError as e:
-            self.fail(
-                "The item: \r\n\r\n %s \r\n\r\n has an issue: \r\n\r\n %s" % (
-                    e.instance, e.context
-                )
-            )
+            self.fail("The item: \r\n\r\n %s \r\n\r\n has an issue: \r\n\r\n %s" % (e.instance, e.context))
 
 
 if __name__ == "__main__":
