@@ -2,23 +2,39 @@ import pandas as pd
 import unittest
 
 from matminer.datasets.tests.base import DatasetTest, do_complete_test
-from matminer.datasets.convenience_loaders import load_glass_ternary_hipt, \
-    load_castelli_perovskites, load_flla, load_boltztrap_mp, \
-    load_citrine_thermal_conductivity, load_dielectric_constant, \
-    load_double_perovskites_gap, load_double_perovskites_gap_lumo, \
-    load_elastic_tensor, load_glass_ternary_landolt, \
-    load_phonon_dielectric_mp, load_piezoelectric_tensor, load_mp, \
-    load_wolverton_oxides, load_heusler_magnetic, load_steel_strength, \
-    load_jarvis_ml_dft_training, load_jarvis_dft_2d, load_jarvis_dft_3d, \
-    load_expt_formation_enthalpy, load_expt_gap, load_glass_binary, load_m2ax, \
-    load_brgoch_superhard_training
+from matminer.datasets.convenience_loaders import (
+    load_glass_ternary_hipt,
+    load_castelli_perovskites,
+    load_flla,
+    load_boltztrap_mp,
+    load_citrine_thermal_conductivity,
+    load_dielectric_constant,
+    load_double_perovskites_gap,
+    load_double_perovskites_gap_lumo,
+    load_elastic_tensor,
+    load_glass_ternary_landolt,
+    load_phonon_dielectric_mp,
+    load_piezoelectric_tensor,
+    load_mp,
+    load_wolverton_oxides,
+    load_heusler_magnetic,
+    load_steel_strength,
+    load_jarvis_ml_dft_training,
+    load_jarvis_dft_2d,
+    load_jarvis_dft_3d,
+    load_expt_formation_enthalpy,
+    load_expt_gap,
+    load_glass_binary,
+    load_m2ax,
+    load_brgoch_superhard_training,
+)
 
 if do_complete_test:
 
     class ConvenienceLoadersTest(DatasetTest):
         def test_load_glass_ternary_hipt(self):
             df = load_glass_ternary_hipt()
-            self. assertTrue(isinstance(df, pd.DataFrame))
+            self.assertTrue(isinstance(df, pd.DataFrame))
 
             with self.assertRaises(AttributeError):
                 df = load_glass_ternary_hipt(system="Nonexistent system")
@@ -157,21 +173,21 @@ if do_complete_test:
             df = load_jarvis_ml_dft_training()
             self.assertTrue(isinstance(df, pd.DataFrame))
             self.assertEqual(len(df), 24759)
-            df = load_jarvis_ml_dft_training(drop_nan_columns='e mass_x')
+            df = load_jarvis_ml_dft_training(drop_nan_columns="e mass_x")
             self.assertEqual(len(df), 19978)
 
         def test_load_jarvis_dft_2d(self):
             df = load_jarvis_dft_2d()
             self.assertTrue(isinstance(df, pd.DataFrame))
             self.assertEqual(len(df), 636)
-            df = load_jarvis_dft_2d(drop_nan_columns='epsilon_x opt')
+            df = load_jarvis_dft_2d(drop_nan_columns="epsilon_x opt")
             self.assertEqual(len(df), 522)
 
         def test_load_jarvis_dft_3d(self):
             df = load_jarvis_dft_3d()
             self.assertTrue(isinstance(df, pd.DataFrame))
             self.assertEqual(len(df), 25923)
-            df = load_jarvis_dft_3d(drop_nan_columns='epsilon_x opt')
+            df = load_jarvis_dft_3d(drop_nan_columns="epsilon_x opt")
             self.assertEqual(len(df), 19027)
 
         def test_load_brgoch_superhard_training(self):
@@ -187,10 +203,10 @@ if do_complete_test:
             df = load_brgoch_superhard_training(subset="basic_descriptors")
             self.assertEqual(len(df), 2574)
             self.assertEqual(len(df.columns), 4)
-            df = load_brgoch_superhard_training(subset="basic_descriptors",
-                                                drop_suspect=True)
+            df = load_brgoch_superhard_training(subset="basic_descriptors", drop_suspect=True)
             self.assertEqual(len(df), 2494)
             self.assertEqual(len(df.columns), 4)
 
+
 if __name__ == "__main__":
     unittest.main()
