@@ -1,6 +1,5 @@
 # coding: utf-8
 
-from __future__ import division, unicode_literals, absolute_import
 import unittest
 from matminer.utils.flatten_dict import flatten_dict
 
@@ -15,7 +14,7 @@ class FlattenDictTest(unittest.TestCase):
 
         deep = {"a": {"b": {"c": {"d": 1}}}}
         deep_flat = flatten_dict(deep)
-        self.assertEqual(deep_flat['a.b.c.d'], 1)
+        self.assertEqual(deep_flat["a.b.c.d"], 1)
 
         # test array functionality
         test2 = {"a": {"b": (0, 1, 2), "c": 2}}
